#!/usr/bin/env bpsh
source lib.tcl

# ARG handling
if { [llength $argv] >= 3 } {
	set host [lindex $argv 1]
	set username [lindex $argv 2]
	set password [lindex $argv 3]
	
	set clientport 0
	set clientinterface 1
	set serverport 1
	set serverinterface 2
} else {
	set scriptname [lindex $argv 0]
	puts "Usage: $scriptname <BPS ipaddr> <username> <password>"
	exit -1
}

# make sure the device isn't in use by another user
if { [catch {set bps [bps::connect $host $username $password -checkversion false]}]} {
	puts "\[!] Error connecting: $errorInfo"
	exit -1
}

puts "\[*] Connected..."

set name "DDoS DNS-2"
puts "\[*] Creating SuperFlow ${name}"
set sf [$bps createSuperflow -name $name]
set count 50

puts "\[*] Creating DNS Server host"
$sf removeHost "Server"
$sf addHost "DNS Server" target "dns.example.com"

puts "\[*] Creating ${count} random hosts"
for {set i 0} { $i < $count} {incr i} {
	set length [expr int(rand()*6)+2] 
	set hostname [randomString $length]
	set domainname "${hostname}.com"
	puts "\[+] $sf addHost $hostname origin $domainname"
	$sf addHost $hostname origin $domainname
}
$sf save -force

puts "\[*] Creating ${count} DNS Queries between Client and Server"
puts "\[+] Adding flow between Client and DNS Server"
set flowid [$sf addFlow dnsadv Client "DNS Server"]

dict for {hostid host} [$sf getHosts] { 
	if {"Client"!=$hostid && "DNS Server"!=$hostid} { 
		puts "\[+] Adding DNS request for $hostid"
		$sf addAction $flowid client dns_query -domainname $hostid -transflag startend
	} 
}

$sf save -force

puts "\[*] Creating App Profile ${name}"
set ap [$bps createAppProfile $name]
$ap addSuperflow $name 100
$ap configure -name $name
$ap save -force

puts "\[*] Creating AppSim ${name}"
set appsim [$bps createComponent appsim $name]
$appsim configure -profile [$ap cget -name]

puts "\[*] Setting Network Neighborhood to DDoS Switching"
$bps setNeighborhood "DDoS Switching"
puts "\[*] Setting interface Domains to DDoS"
$appsim setDomain client $clientinterface "DDoS"
$appsim setDomain server $serverinterface "DDoS"

set name "DDoS DNS-2 Repeated Queries to a Fixed Set of Domain Names"
puts "\[*] Creating test ${name}"
$bps configure -name $name

puts "\[*] Saving Test"
$bps save -force

puts "\[*] Done!"
